@@ -94,52 +94,3 @@ class ActionPlanTests(base.TestCase):
             duration=600,
             sleep_for=2
         ))
-
-
-class ActionPlanActiveTests(base.TestCase):
-
-    audit_uuid = None
-    audit_template_name = 'b' + uuidutils.generate_uuid()
-
-    list_fields = ['UUID', 'Audit', 'State', 'Updated At', 'Global efficacy']
-    detailed_list_fields = list_fields + ['Created At', 'Deleted At',
-                                          'Strategy', 'Efficacy indicators']
-
-    def _delete_action_plan(self):
-        self.assertTrue(test_utils.call_until_true(
-            func=functools.partial(
-                self.has_audit_created, self.audit_uuid),
-            duration=600,
-            sleep_for=2
-        ))
-        output = self.parse_show(
-            self.watcher('actionplan list --audit %s' % self.audit_uuid))
-        action_plan_uuid = list(output[0])[0]
-        raw_output = self.watcher('actionplan delete %s' % action_plan_uuid)
-        self.assertOutput('', raw_output)
-
-    def _delete_audit(self):
-        raw_output = self.watcher('audit delete %s' % self.audit_uuid)
-        self.assertOutput('', raw_output)
-
-    def _delete_audit_template(self):
-        raw_output = self.watcher(
-            'audittemplate delete %s' % self.audit_template_name)
-        self.assertOutput('', raw_output)
-
-    def _create_audit_template(self):
-        template_raw_output = self.watcher(
-            'audittemplate create %s dummy -s dummy'
-            % self.audit_template_name)
-        template_output = self.parse_show_as_object(template_raw_output)
-        return template_output
-
-    def test_action_plan_create(self):
-        template_output = self._create_audit_template()
-        action_plan = self.watcher(
-            'actionplan create -a %s' % template_output['Name'])
-        self.audit_uuid = self.parse_show_as_object(action_plan)['UUID']
-        self.assert_table_structure([action_plan], self.detailed_list_fields)
-        self._delete_action_plan()
-        self._delete_audit()
-        self._delete_audit_template()
